# DS_coding_practices
Clean code practices for data scientists


“When I wrote this code, only God and I understood what I did. Now only God knows.”

If you relate to the above quote, I invite you to a bi-weekly series of “Clean code practices for data scientists.” seminars.

I prepared the first three sessions with the following topics:

1.	Object-oriented pattern for a machine learning problem:
In this session, we work on an exciting ML problem
You work with data class
learn setter and getter
Use str and repl methods
And learn about object lifecycle

And in the following weeks, we are covering:
1.	Programming patterns like Decorators and closure
2.	Packaging


These are potential following topics that may change based on your feedback
1.	Test units
2.	Async.io

Even though you may already know these topics, I still think it might be a good idea to review and see some small tricks that help for better coding.

I am looking forward to sharing my experience and learning from you!
